==> kdissert-0.3.5.tar.bz2: kdissert-0.3.5/src/kdissert/canvasview/DCanvasLink.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Thomas Nagy                                     *
 *   tnagy2^8@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _DCANVASLINK_H
#define _DCANVASLINK_H

#include <qcanvas.h>
#include <qpointarray.h>

class DCanvasLink : public QCanvasRectangle
{
    public:
	DCanvasLink(QCanvas*);
	virtual ~DCanvasLink();
        
	void setPoints(int x1a, int y1a, int x2a, int y2a, 
		int x1b, int y1b, int x2b, int y2b);
	void updateColor();

    protected:
	void drawShape(QPainter &p);
	
    private:
	QPointArray m_pa;
	int m_linkm_x;
	int m_linkm_y;
};

#endif // _DCANVASLINK_H

==> kdissert-0.3.7.tar.bz2: kdissert-0.3.7/src/kdissert/canvasview/DCanvasLink.h <==
/***************************************************************************
 *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
 *   tnagy2^8@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _DCANVASLINK_H
#define _DCANVASLINK_H

#include <qcanvas.h>
#include <qpointarray.h>

class DCanvasItem;

class DCanvasLink : public QCanvasPolygon
{
    public:
	DCanvasLink(QCanvas*, DCanvasItem*);
	virtual ~DCanvasLink();
        
	virtual void updateColor();
	void updatePos();
	void setDest( DCanvasItem* );

	int IdOrig();
	int IdDest();

	static const int Rtti_DCanvasLink = 2222222;
	int rtti() const {return Rtti_DCanvasLink;}

    protected:
	void setPosHide();
	void setPosLines();
	void setPosWeb();
	void setPosCurves();

	DCanvasItem *m_orig;
	DCanvasItem *m_dest;

    private:    
	QPointArray m_pa;
};

#endif // _DCANVASLINK_H
